Some more (trivial) "database tool" -> "audio file selector" conversions
authorAndre <maan@p133.(none)>
Fri, 10 Mar 2006 21:20:31 +0000 (22:20 +0100)
committerAndre <maan@p133.(none)>
Fri, 10 Mar 2006 21:20:31 +0000 (22:20 +0100)
afs.c
command.c
db.c
db.h
mysql_selector.c
playlist_selector.c
random_selector.c
server.h

diff --git a/afs.c b/afs.c
index bbd68d2fc2f1f42e4d0944d800f94405db862128..6c3df15ea814a45d11768cb81c508bf9d0316a72 100644 (file)
--- a/afs.c
+++ b/afs.c
@@ -18,8 +18,8 @@
 
 /** \file afs.c audio file sending functions
  *
 
 /** \file afs.c audio file sending functions
  *
- * This contains the audio sending part of para_server which is independent
- * of the current audio format, database tool and of the activated senders.
+ * This contains the audio sending part of para_server which is independent of
+ * the current audio format, audio file selector and of the activated senders.
  */
 
 #include <sys/time.h> /* gettimeofday */
  */
 
 #include <sys/time.h> /* gettimeofday */
index d1036d1d60886c00705e6690239949a50cad2cb1..9d473019c009f20f5c6f1e4b517712c8a254d49f 100644 (file)
--- a/command.c
+++ b/command.c
@@ -582,7 +582,7 @@ static int com_si(int fd, int argc, __unused char **argv)
                "mallinfo: %d\n"
                "connections (active/accepted/total): %u/%u/%u\n"
                "current loglevel: %i\n"
                "mallinfo: %d\n"
                "connections (active/accepted/total): %u/%u/%u\n"
                "current loglevel: %i\n"
-               "supported database tools: %s\n"
+               "supported audio file selectors: %s\n"
                "supported audio formats: %s\n"
                "supported senders: %s\n"
                "%s",
                "supported audio formats: %s\n"
                "supported senders: %s\n"
                "%s",
@@ -735,7 +735,7 @@ static struct server_command *get_cmd_ptr(char *name, char **handler)
        /* not found, look for commands supported by the current selector */
        mmd_lock();
        if (handler)
        /* not found, look for commands supported by the current selector */
        mmd_lock();
        if (handler)
-               *handler = make_message("the %s database tool", dblist[mmd->dbt_num].name);
+               *handler = make_message("the %s selector", dblist[mmd->dbt_num].name);
        cmd = dblist[mmd->dbt_num].cmd_list;
        mmd_unlock();
        for (; cmd->name; cmd++)
        cmd = dblist[mmd->dbt_num].cmd_list;
        mmd_unlock();
        for (; cmd->name; cmd++)
diff --git a/db.c b/db.c
index d97a6e0e917ffd8b3662ba96d13bbcd37aadefd3..a1cc1aebc09e18c01d2685919bd6c407447d4c8b 100644 (file)
--- a/db.c
+++ b/db.c
@@ -17,7 +17,7 @@
  */
 
 
  */
 
 
-/** \file db.c functions common to all database tools. */
+/** \file db.c functions common to all audio file selectors */
 
 #include "server.cmdline.h"
 #include "server.h"
 
 #include "server.cmdline.h"
 #include "server.h"
--- a/server.h
+++ b/server.h
@@ -139,7 +139,7 @@ struct misc_meta_data{
        unsigned int active_connections;
 /** the process id of para_server */
        pid_t server_pid;
        unsigned int active_connections;
 /** the process id of para_server */
        pid_t server_pid;
-/** a string that gets filled in by the current database tool */
+/** a string that gets filled in by the current audio file selector */
        char dbinfo[MMD_INFO_SIZE];
 /** the number if the current database tool */
        int dbt_num;
        char dbinfo[MMD_INFO_SIZE];
 /** the number if the current database tool */
        int dbt_num;
diff --git a/db.h b/db.h
index 578e4fd9f8ba33ef7626832cb58eb9655ee2d8cd..b136869952eace5d5b05886f2179f2c4a2280245 100644 (file)
--- a/db.h
+++ b/db.h
 int find_audio_files(const char *dirname, int (*f)(const char *, const char *));
 
 /**
 int find_audio_files(const char *dirname, int (*f)(const char *, const char *));
 
 /**
- * describes one of para_server's supported database tools
+ * describes one supported audio file selector
  *
  *
* There is exactly one such struct for each supported database tool.  During
* the startup part of para_server the \a init() function of the activated
* database tool gets called which fills in the other members.
 
  *
  *
  */
 struct audio_file_selector {
 /**
 
  *
  *
  */
 struct audio_file_selector {
 /**
- * name name of this database tool
+ * name name of this selector
  */
 const char *name;
 /**
  */
 const char *name;
 /**
* the database init routine
  *
  * It should check its command line options and do all necessary initialization
  * like connecting to a database server.
  *
  * A negative return value indicates an initialization error and means that
  *
  * It should check its command line options and do all necessary initialization
  * like connecting to a database server.
  *
  * A negative return value indicates an initialization error and means that
* this database tool should be ignored for now (it may later be activated
* again via the cdt command).
  *
  * If \a init() returns success (non-negative return value), it must have
  * initialized in all non-optional function pointers of the given selector
  * struct. Moreover, \a cmd_list must point to a NULL-terminated array which
  *
  * If \a init() returns success (non-negative return value), it must have
  * initialized in all non-optional function pointers of the given selector
  * struct. Moreover, \a cmd_list must point to a NULL-terminated array which
* holds the list of all commands that are supported by this database tool.
  */
 int (*init)(struct audio_file_selector *self);
 /**
  */
 int (*init)(struct audio_file_selector *self);
 /**
@@ -84,20 +84,21 @@ char **(*get_audio_file_list)(unsigned int num);
 void (*update_audio_file)(char *audio_file);
 /**
  *
 void (*update_audio_file)(char *audio_file);
 /**
  *
* shutdown this database tool and free all resources
  *
  *
* This gets called whenever the database tool changes (via the cdt command),
* or when para_server receives the HUP signal, or when para_server shuts down.
* It is assumed to succeed.
  */
 void (*shutdown)(void);
 /**
  *
  * add file descriptors to fd_sets
  *
  */
 void (*shutdown)(void);
 /**
  *
  * add file descriptors to fd_sets
  *
- * The pre_select function of the activated database tool gets called just
- * before para_server enters its main select loop. The selector may add its own
- * file descriptors to the \a rfds or the \a wfds set.
+ * The pre_select function of the activated selector gets called just before
+ * para_server enters its main select loop. The selector may add its own file
+ * descriptors to the \a rfds or the \a wfds set.
  *
  * If a file descriptor was added, \a max_fileno must be increased by
  * this function, if neccessary.
  *
  * If a file descriptor was added, \a max_fileno must be increased by
  * this function, if neccessary.
index 85d16ee200dc9c7bf032aac790894dabee5a710f..88e31f3c3544bbad382e8024e6060c6fbe3d5153 100644 (file)
@@ -93,7 +93,7 @@ static struct server_command cmds[] = {
 
 "\tCreate database name containing the initial columns for basic\n"
 "\tinteroperation with server. This command has to be used only once\n"
 
 "\tCreate database name containing the initial columns for basic\n"
 "\tinteroperation with server. This command has to be used only once\n"
-"\twhen you use the mysql database tool for the very first time.\n"
+"\twhen you use the mysql audio file selector for the very first time.\n"
 "\n"
 "\tThe optional name defaults to 'paraslash' if not given.\n"
 
 "\n"
 "\tThe optional name defaults to 'paraslash' if not given.\n"
 
@@ -212,7 +212,7 @@ static struct server_command cmds[] = {
 .help =
 
 "\tIf pattern was not given, print list of all audio files known\n"
 .help =
 
 "\tIf pattern was not given, print list of all audio files known\n"
-"\tto the mysql database tool. See the documentation of mysql\n"
+"\tto the mysql selector. See the documentation of mysql\n"
 "\tfor the definition of LIKE patterns.\n"
 
 },
 "\tfor the definition of LIKE patterns.\n"
 
 },
@@ -2509,7 +2509,7 @@ static void shutdown_connection(void)
 }
 
 /**
 }
 
 /**
* the init function of the mysql-based database tool
  *
  * Check the command line options and initialize all function pointers of \a db.
  * Connect to the mysql server and initialize the dbinfo string.
  *
  * Check the command line options and initialize all function pointers of \a db.
  * Connect to the mysql server and initialize the dbinfo string.
index f5241d694233c2f852846ba7e439a01727a48beb..f3f556cd6460bbe0af8b941b856fa1b325fc95be 100644 (file)
@@ -65,7 +65,7 @@ static int com_ppl(int, int, char **);
 static int com_lpl(int, int, char **);
 extern struct misc_meta_data *mmd;
 
 static int com_lpl(int, int, char **);
 extern struct misc_meta_data *mmd;
 
-/* array of commands that are supported by this database tool */
+/* array of supported commands */
 static struct server_command cmds[] = {
 {
 .name = "ppl",
 static struct server_command cmds[] = {
 {
 .name = "ppl",
index 43cddb4aa7e92197121d60fe2a71b6eec341a865..37e9116bc24d9ea21e388b7b85576fdeae541525 100644 (file)
@@ -54,7 +54,7 @@ static struct server_command cmds[] = {
 .name = "random_info",
 .handler = com_random_info,
 .perms = 0,
 .name = "random_info",
 .handler = com_random_info,
 .perms = 0,
-.description = "about the random database tool",
+.description = "about the random audio file selector",
 .synopsis = "random_info",
 .help =
 
 .synopsis = "random_info",
 .help =
 
@@ -128,7 +128,7 @@ static void random_shutdown(void)
 #define DBINFO "dbinfo1:database info? You're kidding. I'm still dopey!\ndbinfo2:\ndbinfo3:\n"
 
 /**
 #define DBINFO "dbinfo1:database info? You're kidding. I'm still dopey!\ndbinfo2:\ndbinfo3:\n"
 
 /**
- *  the init function for the random database tool
+ *  the init function for the random audio file selector
  *
  * Init all function pointers of \a db, init the dbinfo text and seed the
  * PRNG.
@@
  *
  *
- * There is exactly one such struct for each supported database tool.  During
- * the startup part of para_server the \a init() function of the activated
- * database tool gets called which fills in the other members.
+ * There is one such struct for each supported selector.  During the startup
+ * part of para_server the \a init() function of the activated selector gets
+ * called which fills in all other function pointers.
 
  *
@@
 const char *name;
 /**
- * the database init routine
+ * the init routine of the selector
  *
  * It should check its command line options and do all necessary initialization
@@
  *
  * A negative return value indicates an initialization error and means that
- * this database tool should be ignored for now (it may later be activated
- * again via the cdt command).
+ * this selector should be ignored for now (it may later be activated again via
+ * the chs command).
  *
  * If \a init() returns success (non-negative return value), it must have
@@
  * initialized in all non-optional function pointers of the given selector
  * struct. Moreover, \a cmd_list must point to a NULL-terminated array which
- * holds the list of all commands that are supported by this database tool.
+ * holds the list of all commands that are supported by this selector.
  */
 int (*init)(struct audio_file_selector *self);
@@ -84,20 +84,21 @@ char **(*get_audio_file_list)(unsigned int num);
 /**
  *
- * shutdown this database tool and free all resources
+ * shutdown this selector and free all resources
  *
  *
@@ -84,20 +84,21 @@ char **(*get_audio_file_list)(unsigned int num);
  *
  *
- * This gets called whenever the database tool changes (via the cdt command),
- * or when para_server receives the HUP signal, or when para_server shuts down.
- * It is assumed to succeed.
+ * This gets called whenever the audio file selector changes. The reason for
+ * this change might be that some user sent the chs command, that para_server
+ * receives the HUP signal, or that para_server shuts down. It is assumed to
+ * succeed.
  */
 void (*shutdown)(void);
@@ -2509,7 +2509,7 @@ static void shutdown_connection(void)
 
 /**
- * the init function of the mysql-based database tool
+ * the init function of the mysql-based audio file selector
  *
  * Check the command line options and initialize all function pointers of \a db.
  *
  * Init all function pointers of \a db, init the dbinfo text and seed the
  * PRNG.
index fe6d858199c97a5a27ed586b76a6c8078840ad63..1e4a75f83e514c5a5537a5850c4bdca5888f3323 100644 (file)